@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import inspect
 import types
-import typing
+from typing import Any, List, Type, TypeVar
 
 from .serialization import FormatListType, Payload
 
@@ -28,7 +28,7 @@ class VariablePayload(Payload):
     want to apply when actually sending over the wire.
     """
 
-    names: typing.List[str] = []
+    names: List[str] = []
 
     def __init__(self, *args, **kwargs):
         """
@@ -65,6 +65,7 @@ class VariablePayload(Payload):
             raise KeyError("%s missing %d arguments!" % (self.__class__.__name__, len(args) - index))
         if kwargs:
             raise KeyError("%s has leftover keyword arguments: %s!" % (self.__class__.__name__, str(kwargs)))
+        self.__class__.__match_args__ = tuple(self.names)
 
     @classmethod
     def from_unpack_list(cls, *args) -> VariablePayload:
@@ -88,7 +89,7 @@ class VariablePayload(Payload):
             return 'payload-list'
         return 'payload'
 
-    def _fix_pack(self, name: str) -> typing.Any:
+    def _fix_pack(self, name: str) -> Any:
         """
         Check if there are custom rules for sending this field.
         """
@@ -98,7 +99,7 @@ class VariablePayload(Payload):
             return getattr(self, custom_rule)(raw_value)
         return raw_value
 
-    def to_pack_list(self) -> typing.List[tuple]:
+    def to_pack_list(self) -> List[tuple]:
         """
         Convert the VariablePayload to a Serializable pack list.
         This method will automatically pull from the available format names and set instance fields.
@@ -116,7 +117,11 @@ class VariablePayload(Payload):
         return out
 
 
-def _compile_init(names: typing.List[str]) -> types.CodeType:
+V = TypeVar('V', bound=VariablePayload)
+VT = Type[V]
+
+
+def _compile_init(names: List[str]) -> types.CodeType:
     """
     Compile the init function.
 
@@ -142,7 +147,7 @@ def __init__(self, %s):
     return compile(f_code, f_code, 'exec')
 
 
-def _compile_from_unpack_list(src_cls: typing.Type[VariablePayload], names: typing.List[str]) -> types.CodeType:
+def _compile_from_unpack_list(src_cls: VT, names: List[str]) -> types.CodeType:
     """
     Compile the unpacking code.
 
@@ -170,9 +175,7 @@ def from_unpack_list(cls, %s):
     return compile(f_code, f_code, 'exec')
 
 
-def _compile_to_pack_list(src_cls: typing.Type[VariablePayload],
-                          format_list: typing.List[FormatListType],
-                          names: typing.List[str]) -> types.CodeType:
+def _compile_to_pack_list(src_cls: VT, format_list: List[FormatListType], names: List[str]) -> types.CodeType:
     """
     Compile the packing code.
 
@@ -213,7 +216,7 @@ def to_pack_list(self):
     return compile(f_code, f_code, 'exec')
 
 
-def vp_compile(vp_definition: typing.Type[VariablePayload]) -> typing.Type[VariablePayload]:
+def vp_compile(vp_definition: VT) -> VT:
     """
     JIT Compilation of a VariablePayload definition.
     """
@@ -229,6 +232,7 @@ def vp_compile(vp_definition: typing.Type[VariablePayload]) -> typing.Type[Varia
     # Rewrite the class methods from the locally loaded overwrites.
     # from_unpack_list is a classmethod, so we need to scope it properly.
     setattr(vp_definition, '__init__', locals()['__init__'])
+    setattr(vp_definition, '__match_args__', tuple(vp_definition.names))
     setattr(vp_definition, 'from_unpack_list', types.MethodType(locals()['from_unpack_list'], vp_definition))
     setattr(vp_definition, 'to_pack_list', locals()['to_pack_list'])
     return vp_definition
