@@ -1,6 +1,10 @@
+import base64
+
 from .base import TestBase
 from ..configuration import (Bootstrapper, BootstrapperDefinition, ConfigBuilder, DISPERSY_BOOTSTRAPPER, Strategy,
                              WalkerDefinition, get_default_configuration)
+from ..keyvault.crypto import default_eccrypto
+from ..keyvault.private.libnaclkey import LibNaCLSK
 
 
 class TestConfiguration(TestBase):
@@ -26,37 +30,13 @@ class TestConfiguration(TestBase):
 
         self.assertEqual(0, len(builder.finalize()['overlays']))
 
-    def test_add_illegal_port_negative(self):
-        """
-        Check if negative ports raise an error on finalization.
-        """
-        builder = ConfigBuilder().set_port(-1)
-
-        self.assertRaises(AssertionError, builder.finalize)
-
-    def test_add_illegal_port_big(self):
-        """
-        Check if ports over 65535 raise an error on finalization.
-        """
-        builder = ConfigBuilder().set_port(100000)
-
-        self.assertRaises(AssertionError, builder.finalize)
-
     def test_change_port(self):
         """
         Check if changes to the port are finalized.
         """
         builder = ConfigBuilder().set_port(1000)
 
-        self.assertEqual(1000, builder.finalize()['port'])
-
-    def test_add_illegal_address(self):
-        """
-        Check if wrong IP addresses raise an error immediately.
-        """
-        builder = ConfigBuilder()
-
-        self.assertRaises(AssertionError, builder.set_address, "1.1.1")
+        self.assertEqual(1000, builder.finalize()['interfaces'][0]['port'])
 
     def test_change_address(self):
         """
@@ -64,7 +44,7 @@ class TestConfiguration(TestBase):
         """
         builder = ConfigBuilder().set_address("1.1.1.1")
 
-        self.assertEqual("1.1.1.1", builder.finalize()['address'])
+        self.assertEqual("1.1.1.1", builder.finalize()['interfaces'][0]['ip'])
 
     def test_set_illegal_log_level(self):
         """
@@ -122,6 +102,56 @@ class TestConfiguration(TestBase):
         self.assertEqual(1 + len(get_default_configuration()['keys']), len(keys))
         self.assertTrue(any(set(entry.items()) == set(expected.items()) for entry in keys))
 
+    def test_add_key_from_bin(self):
+        """
+        Check if changes to the keys are finalized in bin mode.
+        """
+        key_material = ("MG0CAQEEHUkphrkiuNhcofjWfaplwoAk0i7tBIDq93ATwaTKoAcGBSuBBAAaoUADPgAEANBoqp"
+                        "ZtJ3z0fbt2knDEBC6nLk2P0AHEWKHoCOzRAAloM3NgRObfmRlkuiQANY0VWRMn1TAjIZqogwBD")
+        builder = ConfigBuilder().add_key_from_bin("my new key", key_material)
+
+        expected = {
+            'alias': "my new key",
+            'bin': key_material
+        }
+        keys = builder.finalize()['keys']
+
+        self.assertEqual(1 + len(get_default_configuration()['keys']), len(keys))
+        self.assertTrue(any(set(entry.items()) == set(expected.items()) for entry in keys))
+
+    def test_add_key_from_bin_file(self):
+        """
+        Check if changes to the keys are finalized in bin mode with a file.
+        """
+        key_material = ("MG0CAQEEHUkphrkiuNhcofjWfaplwoAk0i7tBIDq93ATwaTKoAcGBSuBBAAaoUADPgAEANBoqp"
+                        "ZtJ3z0fbt2knDEBC6nLk2P0AHEWKHoCOzRAAloM3NgRObfmRlkuiQANY0VWRMn1TAjIZqogwBD")
+        builder = ConfigBuilder().add_key_from_bin("my new key", key_material, "some file")
+
+        expected = {
+            'alias': "my new key",
+            'bin': key_material,
+            'file': "some file"
+        }
+        keys = builder.finalize()['keys']
+
+        self.assertEqual(1 + len(get_default_configuration()['keys']), len(keys))
+        self.assertTrue(any(set(entry.items()) == set(expected.items()) for entry in keys))
+
+    def test_add_ephemeral_key(self):
+        """
+        Check if ephemeral keys are created correctly.
+        """
+        builder = ConfigBuilder().add_ephemeral_key("my new key")
+
+        expected_keys = {'alias', 'bin', 'file'}
+        keys = builder.finalize()['keys']
+
+        self.assertEqual(1 + len(get_default_configuration()['keys']), len(keys))
+        self.assertTrue(any(entry.keys() == expected_keys for entry in keys))
+        self.assertEqual("my new key", keys[-1]["alias"])
+        self.assertEqual("", keys[-1]["file"])
+        self.assertIsInstance(default_eccrypto.key_from_private_bin(base64.b64decode(keys[-1]["bin"])), LibNaCLSK)
+
     def test_add_overlay_overwrite(self):
         """
         Check if the allow duplicate flag does not introduce duplicates.
@@ -196,32 +226,6 @@ class TestConfiguration(TestBase):
 
         self.assertDictInDict(expected, builder.finalize()['overlays'])
 
-    def test_illegal_random_churn_strategy(self):
-        """
-        Only the DiscoveryCommunity may use the RandomChurn strategy.
-        """
-        builder = ConfigBuilder().add_overlay("MyCommunity",
-                                              "anonymous id",
-                                              [WalkerDefinition(Strategy.RandomChurn, 20, {})],
-                                              [],
-                                              {},
-                                              [])
-
-        self.assertRaises(AssertionError, builder.finalize)
-
-    def test_illegal_periodic_similarity_strategy(self):
-        """
-        Only the DiscoveryCommunity may use the PeriodicSimilarity strategy.
-        """
-        builder = ConfigBuilder().add_overlay("MyCommunity",
-                                              "anonymous id",
-                                              [WalkerDefinition(Strategy.PeriodicSimilarity, 20, {})],
-                                              [],
-                                              {},
-                                              [])
-
-        self.assertRaises(AssertionError, builder.finalize)
-
     def test_correct_random_churn_strategy(self):
         """
         The DiscoveryCommunity may use the RandomChurn strategy.
